@@ -18,10 +18,10 @@
 */
 
 #include "notificationmessagetest.h"
-#include "notificationmessagetest.moc"
 
 #include <notificationmessage_p.h>
 
+#include <QSet>
 #include <QtTest/QTest>
 
 QTEST_APPLESS_MAIN( NotificationMessageTest )
