@@ -23,17 +23,11 @@
 #include <QByteArray>
 #include <QStringList>
 
-namespace Akonadi {
-namespace Server {
-
 /// Details of a single item retrieval request
 class ItemRetrievalRequest
 {
   public:
-    ItemRetrievalRequest()
-      : processed( false )
-    {
-    }
+    ItemRetrievalRequest() : processed( false ) {}
     qint64 id;
     QByteArray remoteId;
     QByteArray mimeType;
@@ -45,7 +39,4 @@ class ItemRetrievalRequest
     Q_DISABLE_COPY( ItemRetrievalRequest )
 };
 
-} // namespace Server
-} // namespace Akonadi
-
 #endif
