@@ -28,6 +28,7 @@
 #include "storage/itemretrievalrequest.h"
 #include "storage/parthelper.h"
 #include "storage/querybuilder.h"
+#include "storage/selectquerybuilder.h"
 #include "utils.h"
 
 #include <QDebug>
@@ -176,6 +177,8 @@ bool ItemRetriever::exec()
   if ( mParts.isEmpty() && !mFullPayload )
     return true;
 
+  verifyCache();
+
   QSqlQuery query = buildQuery();
   ItemRetrievalRequest* lastRequest = 0;
   QList<ItemRetrievalRequest*> requests;
@@ -256,9 +259,25 @@ bool ItemRetriever::exec()
   return result;
 }
 
-QString ItemRetriever::driverName()
+void ItemRetriever::verifyCache()
 {
-  return mConnection->storageBackend()->database().driverName();
+  SelectQueryBuilder<Part> qb;
+  qb.addJoin( QueryBuilder::InnerJoin, PimItem::tableName(), Part::pimItemIdFullColumnName(), PimItem::idFullColumnName() );
+  qb.addValueCondition( Part::externalFullColumnName(), Query::Equals, true );
+  qb.addValueCondition( Part::dataFullColumnName(), Query::IsNot, QVariant() );
+  if ( mScope.scope() != Scope::Invalid )
+    ItemQueryHelper::scopeToQuery( mScope, mConnection, qb );
+  else
+    ItemQueryHelper::itemSetToQuery( mItemSet, qb, mCollection );
+
+  if (!qb.exec()) {
+    mLastError = "Unable to query parts.";
+    throw ItemRetrieverException( mLastError );
+  }
+
+  const Part::List externalParts = qb.result();
+  Q_FOREACH ( Part part, externalParts )
+    PartHelper::verify( part );
 }
 
 QByteArray ItemRetriever::lastError() const
